@@ -3,8 +3,12 @@ import pandas as pd
 
 
 data = pd.read_csv(r"tests/mtsamples.csv")
+
+data[data["medical_specialty"] == " Dentistry"]
+
 data = data.sort_values("medical_specialty")
 
+
 new_list = list(
     data[data["medical_specialty"] == "Dentistry"]["transcription"]
 )
@@ -18,10 +22,12 @@ data = data.drop_duplicates(
 )  # , 'medical_specialty'], keep="first")
 
 
+
 data = data.drop(data[data["transcription"].isna()].index)
 
 data = data[["dentistry", "transcription", "medical_specialty"]]
 
 data = data[["transcription"]]
+data = data.reset_index(drop=True)
 if __name__ == "__main__":
-    print(data)
+    print(data.reset_index(drop=True))
